{% extends "overseer/base.html" %}

{% load overseer_helpers %}

{% block content %}
    <h3>Unsubscribed</h3>

    <p>You will no longer receive updates at <strong>{{ email }}</strong>.</p>

{% endblock %}