<!doctype html>

<!--[if lt IE 7 ]> <html lang="en" class="no-js ie6"> <![endif]-->
<!--[if IE 7 ]>    <html lang="en" class="no-js ie7"> <![endif]-->
<!--[if IE 8 ]>    <html lang="en" class="no-js ie8"> <![endif]-->
<!--[if IE 9 ]>    <html lang="en" class="no-js ie9"> <![endif]-->
<!--[if (gt IE 9)|!(IE)]><!--> <html lang="en" class="no-js"> <!--<![endif]-->
<head>
  <meta charset="utf-8">
  <meta http-equiv="X-UA-Compatible" content="IE=edge,chrome=1">

  <title>{{ OVERSEER_TITLE }}</title>
  <meta name="description" content="">
  <meta name="author" content="">

  <meta name="viewport" content="width=device-width, initial-scale=1.0">
  <link rel="shortcut icon" href="{{ OVERSEER_MEDIA_PREFIX }}/favicon.png">
  <link rel="apple-touch-icon" href="{{ OVERSEER_MEDIA_PREFIX }}/apple-touch-icon.png">
  <link rel="stylesheet" href="{{ OVERSEER_MEDIA_PREFIX }}/css/base.css">
</head>

<body>

  <div id="container">
    <header>
        <div class="wrapper">
            <h1><a href="{% url overseer:index %}">{{ OVERSEER_NAME }}</a></h1>
        </div>
    </header>
    
    <div id="main" class="main">
        <div class="wrapper">
            <div class="clearfix">
                {% block content %}{% endblock %}
                {% if OVERSEER_ALLOW_SUBSCRIPTIONS %}
                    <p>Want to get notified when things change? <a href="{% url overseer:create_subscription %}">Subscribe to status updates</a>.</p>
                {% endif %}
            </div>
        </div>
    </div>
    
    <footer>
        <div class="wrapper">
            Powered by <a href="https://github.com/disqus/overseer">Overseer {{ OVERSEER_VERSION }}</a> | Conjured up by the <a href="http://code.disqus.com">DISQUS</a> team and other noble <a href="https://github.com/disqus/overseer/contributors">sorcerers</a>. | <a href="{% url admin:index %}">Admin</a>
        </div>
    </footer>
  </div> <!-- end of #container -->  
</body>
</html>