{% extends "overseer/base.html" %}

{% load overseer_helpers %}

{% block content %}
    <h3>Error</h3>

    <p>The subscription token for your request is not valid. Maybe you already confirmed your subscription?</p>

{% endblock %}